@@ -74,7 +74,8 @@ const char* subdevnames[4]={
 MODULE_AUTHOR("Peter Wuestner <P.Wuestner@fz-juelich.de>");
 MODULE_DESCRIPTION("SIS1100 PCI-VME link/interface");
 MODULE_LICENSE("Dual BSD/GPL");
-MODULE_SUPPORTED_DEVICE("sis1100/sis3100/sis5100; http://www.struck.de/pcivme.htm");
+
+//MODULE_SUPPORTED_DEVICE("sis1100/sis3100/sis5100; http://www.struck.de/pcivme.htm");
 
 #define DRIVER_VERSION "2.14"
 #define DATE_STRING "2019-05-22"
@@ -87,7 +88,7 @@ struct file_operations sis1100_fops = {
 	.llseek  = sis1100_llseek,
 	.read    = sis1100_read,
 	.write   = sis1100_write,
-#ifdef HAVE_UNLOCKED_IOCTL
+#if (LINUX_VERSION_CODE > KERNEL_VERSION(5, 9, 0)) || defined (HAVE_UNLOCKED_IOCTL)
 	.unlocked_ioctl = sis1100_ioctl,
 #else
 	.ioctl   = sis1100_ioctl,
@@ -262,11 +263,15 @@ init_sis1100_device(struct pci_dev *pdev, const struct pci_device_id *ent)
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,11)
         sc->sched_param.sched_priority=20;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5,9,0)        
+        sched_set_fifo(sc->handler);
+#else
         res=sched_setscheduler(sc->handler, SCHED_FIFO, &sc->sched_param);
         if (res!=0) {
             pINFO(sc, "sched_setscheduler: %d", res);
         }
 #endif
+#endif
 
 #if 1
 	res=pci_enable_device(pdev);
